@@ -51,6 +51,12 @@ module Nokogiri
         @list.each { |x| assert_nil x['class'] }
       end
 
+      def test_remove_attribute
+        @list.each { |x| x['class'] = 'blah' }
+        assert_equal @list, @list.remove_attribute('class')
+        @list.each { |x| assert_nil x['class'] }
+      end
+
       def test_add_class
         assert_equal @list, @list.add_class('bar')
         @list.each { |x| assert_equal 'bar', x['class'] }
@@ -62,6 +68,17 @@ module Nokogiri
         @list.each { |x| assert_equal 'bar baz', x['class'] }
       end
 
+      def test_append_class
+        assert_equal @list, @list.append_class('bar')
+        @list.each { |x| assert_equal 'bar', x['class'] }
+
+        @list.append_class('bar')
+        @list.each { |x| assert_equal 'bar bar', x['class'] }
+
+        @list.append_class('baz')
+        @list.each { |x| assert_equal 'bar bar baz', x['class'] }
+      end
+
       def test_remove_class_with_no_class
         assert_equal @list, @list.remove_class('bar')
         @list.each { |e| assert_nil e['class'] }
@@ -251,6 +268,11 @@ module Nokogiri
         assert node_set = @xml.xpath('//employee')
         assert_equal 2, node_set.first(2).length
       end
+      
+      def test_first_clamps_arguments
+        assert node_set = @xml.xpath('//employee[position() < 3]')
+        assert_equal 2, node_set.first(5).length
+      end
 
       [:dup, :clone].each do |method_name|
         define_method "test_#{method_name}" do
@@ -403,7 +425,7 @@ module Nokogiri
       def test_delete_on_empty_set
         empty_set = Nokogiri::XML::NodeSet.new @xml, []
         employee  = @xml.at_xpath("//employee")
-        assert_equal nil, empty_set.delete(employee)
+        assert_nil empty_set.delete(employee)
       end
 
       def test_unlink
@@ -558,6 +580,8 @@ module Nokogiri
 
         assert_equal 3, employees.index(employees[3])
         assert_nil employees.index(other)
+        assert_equal 3, employees.index {|employee| employee.search("employeeId/text()").to_s == "EMP0004" }
+        assert_nil employees.index {|employee| employee.search("employeeId/text()").to_s == "EMP0000" }
       end
 
       def test_slice_too_far
@@ -568,9 +592,9 @@ module Nokogiri
 
       def test_slice_on_empty_node_set
         empty_set = Nokogiri::XML::NodeSet.new @xml, []
-        assert_equal nil, empty_set[99]
-        assert_equal nil, empty_set[99..101]
-        assert_equal nil, empty_set[99,2]
+        assert_nil empty_set[99]
+        assert_nil empty_set[99..101]
+        assert_nil empty_set[99,2]
       end
 
       def test_slice_waaaaaay_off_the_end
@@ -648,6 +672,14 @@ module Nokogiri
         assert ! empty_set.include?(employee)
       end
 
+      def test_each
+        employees = @xml.search("//employee")
+        enum = employees.each
+        assert_instance_of Enumerator, enum
+        assert_equal enum.next, employees[0]
+        assert_equal enum.next, employees[1]
+      end
+
       def test_children
         employees = @xml.search("//employee")
         count = 0
